@@ -623,6 +623,20 @@ def AddSourceIpRanges(parser):
       """)
 
 
+def AddTrafficDisabled(parser):
+  """Adds traffic disabled flag to the argparse."""
+  parser.add_argument(
+      '--traffic-disabled',
+      action='store_true',
+      default=False,
+      help="""\
+      If set to true, disables traffic from flowing through Private Service
+      Connect forwarding rule from consumer to producer. This can
+      only be specified if the forwarding rule's target is a service attachment
+      (`--target-service-attachment`).
+      """)
+
+
 def AddAllowGlobalAccess(parser):
   """Adds allow global access flag to the argparse."""
   parser.add_argument(
@@ -815,15 +829,15 @@ def AddExternalMigration(parser):
       type=lambda x: x.replace('-', '_').upper(),
       default=None,
       help="""\
-      Specifies the canary migration state. Possible values are PREPARE,
+      Specifies the migration state. Possible values are PREPARE,
       TEST_BY_PERCENTAGE, and TEST_ALL_TRAFFIC.
 
       To begin the migration from EXTERNAL to EXTERNAL_MANAGED, the state must
       be changed to PREPARE. The state must be changed to TEST_ALL_TRAFFIC
       before the loadBalancingScheme can be changed to EXTERNAL_MANAGED.
       Optionally, the TEST_BY_PERCENTAGE state can be used to migrate traffic to
-      backend buckets attached to this forwarding rule by percentage using
-      externalManagedBackendBucketMigrationTestingPercentage.
+      backend buckets attached to this forwarding rule by percentage using the
+      --external-managed-backend-bucket-migration-testing-percentage flag.
     """,
   )
   group.add_argument(
@@ -847,7 +861,7 @@ def AddExternalMigration(parser):
       '--load-balancing-scheme',
       choices=['EXTERNAL', 'EXTERNAL_MANAGED'],
       help="""\
-      Only for the Global external ALB migration.
+      Only for the Global external Application Load Balancer migration.
 
       The value of this field must be EXTERNAL or EXTERNAL_MANAGED.
     """,
