@@ -30,6 +30,7 @@ __protobuf__ = proto.module(
     package='google.cloud.aiplatform.v1beta1',
     manifest={
         'Tool',
+        'UrlContext',
         'ToolUseExample',
         'FunctionDeclaration',
         'FunctionCall',
@@ -41,6 +42,7 @@ __protobuf__ = proto.module(
         'VertexAISearch',
         'ExternalApi',
         'GoogleSearchRetrieval',
+        'GoogleMaps',
         'EnterpriseWebSearch',
         'DynamicRetrievalConfig',
         'ToolConfig',
@@ -71,7 +73,7 @@ class Tool(proto.Message):
             [FunctionResponse][google.cloud.aiplatform.v1beta1.Part.function_response]
             for each function call in the next turn. Based on the
             function responses, Model will generate the final response
-            back to the user. Maximum 128 function declarations can be
+            back to the user. Maximum 512 function declarations can be
             provided.
         retrieval (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.Retrieval):
             Optional. Retrieval tool type.
@@ -87,6 +89,9 @@ class Tool(proto.Message):
             Optional. GoogleSearchRetrieval tool type.
             Specialized retrieval tool that is powered by
             Google search.
+        google_maps (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.GoogleMaps):
+            Optional. GoogleMaps tool type.
+            Tool to support Google Maps in Model.
         enterprise_web_search (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.EnterpriseWebSearch):
             Optional. Tool to support searching public
             web data, powered by Vertex AI Search and Sec4
@@ -95,14 +100,27 @@ class Tool(proto.Message):
             Optional. CodeExecution tool type.
             Enables the model to execute code as part of
             generation.
+        url_context (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.UrlContext):
+            Optional. Tool to support URL context
+            retrieval.
     """
 
     class GoogleSearch(proto.Message):
         r"""GoogleSearch tool type.
         Tool to support Google Search in Model. Powered by Google.
 
+        Attributes:
+            exclude_domains (MutableSequence[str]):
+                Optional. List of domains to be excluded from the search
+                results. The default limit is 2000 domains. Example:
+                ["amazon.com", "facebook.com"].
         """
 
+        exclude_domains: MutableSequence[str] = proto.RepeatedField(
+            proto.STRING,
+            number=3,
+        )
+
     class CodeExecution(proto.Message):
         r"""Tool that executes code generated by the model, and automatically
         returns the result to the model.
@@ -132,6 +150,11 @@ class Tool(proto.Message):
         number=3,
         message='GoogleSearchRetrieval',
     )
+    google_maps: 'GoogleMaps' = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message='GoogleMaps',
+    )
     enterprise_web_search: 'EnterpriseWebSearch' = proto.Field(
         proto.MESSAGE,
         number=6,
@@ -142,6 +165,16 @@ class Tool(proto.Message):
         number=4,
         message=CodeExecution,
     )
+    url_context: 'UrlContext' = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message='UrlContext',
+    )
+
+
+class UrlContext(proto.Message):
+    r"""Tool to support URL context.
+    """
 
 
 class ToolUseExample(proto.Message):
@@ -274,12 +307,37 @@ class FunctionDeclaration(proto.Message):
             required:
 
              - param1
+        parameters_json_schema (google.protobuf.struct_pb2.Value):
+            Optional. Describes the parameters to the function in JSON
+            Schema format. The schema must describe an object where the
+            properties are the parameters to the function. For example:
+
+            ::
+
+               {
+                 "type": "object",
+                 "properties": {
+                   "name": { "type": "string" },
+                   "age": { "type": "integer" }
+                 },
+                 "additionalProperties": false,
+                 "required": ["name", "age"],
+                 "propertyOrdering": ["name", "age"]
+               }
+
+            This field is mutually exclusive with ``parameters``.
         response (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.Schema):
             Optional. Describes the output from this
             function in JSON Schema format. Reflects the
             Open API 3.03 Response Object. The Schema
             defines the type used for the response value of
             the function.
+        response_json_schema (google.protobuf.struct_pb2.Value):
+            Optional. Describes the output from this function in JSON
+            Schema format. The value specified by the schema is the
+            response value of the function.
+
+            This field is mutually exclusive with ``response``.
     """
 
     name: str = proto.Field(
@@ -295,11 +353,21 @@ class FunctionDeclaration(proto.Message):
         number=3,
         message=openapi.Schema,
     )
+    parameters_json_schema: struct_pb2.Value = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=struct_pb2.Value,
+    )
     response: openapi.Schema = proto.Field(
         proto.MESSAGE,
         number=4,
         message=openapi.Schema,
     )
+    response_json_schema: struct_pb2.Value = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=struct_pb2.Value,
+    )
 
 
 class FunctionCall(proto.Message):
@@ -545,6 +613,15 @@ class VertexRagStore(proto.Message):
         rag_retrieval_config (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.RagRetrievalConfig):
             Optional. The retrieval config for the Rag
             query.
+        store_context (bool):
+            Optional. Currently only supported for Gemini Multimodal
+            Live API.
+
+            In Gemini Multimodal Live API, if ``store_context`` bool is
+            specified, Gemini will leverage it to automatically memorize
+            the interactions between the client and Gemini, and retrieve
+            context when needed to augment the response generation for
+            users' ongoing and future interactions.
     """
 
     class RagResource(proto.Message):
@@ -592,6 +669,10 @@ class VertexRagStore(proto.Message):
         number=6,
         message='RagRetrievalConfig',
     )
+    store_context: bool = proto.Field(
+        proto.BOOL,
+        number=7,
+    )
 
 
 class VertexAISearch(proto.Message):
@@ -806,12 +887,47 @@ class GoogleSearchRetrieval(proto.Message):
     )
 
 
+class GoogleMaps(proto.Message):
+    r"""Tool to retrieve public maps data for grounding, powered by
+    Google.
+
+    Attributes:
+        api_auth (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ApiAuth):
+            The authentication config to access the API. Deprecated.
+            Please use auth_config instead.
+        auth_config (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.AuthConfig):
+            The authentication config to access the API.
+            Only API key is supported.
+    """
+
+    api_auth: gca_api_auth.ApiAuth = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gca_api_auth.ApiAuth,
+    )
+    auth_config: auth.AuthConfig = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=auth.AuthConfig,
+    )
+
+
 class EnterpriseWebSearch(proto.Message):
     r"""Tool to search public web data, powered by Vertex AI Search
     and Sec4 compliance.
 
+    Attributes:
+        exclude_domains (MutableSequence[str]):
+            Optional. List of domains to be excluded from
+            the search results. The default limit is 2000
+            domains.
     """
 
+    exclude_domains: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+
 
 class DynamicRetrievalConfig(proto.Message):
     r"""Describes the options to customize dynamic retrieval.
