@@ -49,6 +49,7 @@ from googlecloudsdk.core.console import console_io
 from googlecloudsdk.core.console import progress_tracker
 
 _PROJECT_TOML_FILE_NAME = 'project.toml'
+_GPU_BUILD_MACHINE_TYPE = 'E2_HIGHCPU_8'
 
 
 class BuildType(enum.Enum):
@@ -85,10 +86,12 @@ they will apply to the primary ingress container.
   group.AddArgument(flags.BuildServiceAccountMutexGroup())
   group.AddArgument(flags.BuildWorkerPoolMutexGroup())
   group.AddArgument(flags.MutexBuildEnvVarsFlags())
-  group.AddArgument(flags.SourceAndImageFlags(mutex=False))
+  group.AddArgument(
+      flags.SourceAndImageFlags(mutex=False, release_track=release_track)
+  )
   group.AddArgument(flags.StartupProbeFlag())
   group.AddArgument(flags.LivenessProbeFlag())
-  group.AddArgument(flags.GpuFlag(hidden=False))
+  group.AddArgument(flags.GpuFlag())
 
   return group
 
@@ -129,11 +132,12 @@ class Deploy(base.Command):
     flags.AddCmekKeyRevocationActionTypeFlag(parser)
     flags.AddCpuThrottlingFlag(parser)
     flags.AddCustomAudiencesFlag(parser)
+    flags.AddDefaultUrlFlag(parser)
     flags.AddDescriptionFlag(parser)
     flags.AddEgressSettingsFlag(parser)
     flags.AddEncryptionKeyShutdownHoursFlag(parser)
-    flags.AddGpuTypeFlag(parser, hidden=False)
-    flags.GpuZonalRedundancyFlag(parser, hidden=False)
+    flags.AddGpuTypeFlag(parser)
+    flags.GpuZonalRedundancyFlag(parser)
     flags.AddRevisionSuffixArg(parser)
     flags.AddSandboxArg(parser)
     flags.AddSessionAffinityFlag(parser)
@@ -291,8 +295,45 @@ class Deploy(base.Command):
               '--image',
               message,
           )
+    self._ValidateNoBuildFromSource(build_from_source)
     return build_from_source
 
+  def _ValidateNoBuildFromSource(self, build_from_source):
+    """Extra validation for Zip deployments.
+
+    This is a no-op for if the --no-build flag is not set.
+
+    Args:
+      build_from_source: The build from source map of container name to
+        container object.
+    """
+    if not _IsNoBuildFromSource(self.ReleaseTrack(), build_from_source):
+      return
+
+    # TODO(b/424567464): Remove this check once we support multiple containers
+    # with --no-build.
+    container = next(iter(build_from_source.items()))[1]
+    if not container.IsSpecified('base_image'):
+      raise c_exceptions.InvalidArgumentException(
+          '--no-build',
+          'Source deployment must specify --base-image when skipping'
+          'Cloud Build.',
+      )
+    if not container.IsSpecified('command'):
+      raise c_exceptions.InvalidArgumentException(
+          '--no-build',
+          'Source deployment must specify --command when skipping Cloud Build.',
+      )
+    if (
+        container.IsSpecified('image')
+        and getattr(container, 'image') != 'scratch'
+    ):
+      raise c_exceptions.InvalidArgumentException(
+          '--image',
+          'Source deployment --image must be set to "scratch" when skipping'
+          'Cloud Build.',
+      )
+
   def _GetBaseImageForSourceContainer(self, container_args, service):
     """Returns the base image for the container.
 
@@ -357,6 +398,39 @@ class Deploy(base.Command):
       return True if automatic_updates_annotation.lower() == 'true' else False
     return automatic_updates
 
+  def _GetMachineType(self, container_args, service):
+    """Gets the default pool build machine type to use based on the user flags and annotations.
+
+    User flags take precedence over annotations for an existing service.
+
+    Args:
+      container_args: base.ArgumentGroup, Container arguments using source
+        build.
+      service: Service, existing Cloud run service.
+
+    Returns:
+      build_machine_type or
+      None meaning default machine type should be used
+    """
+    gpu_type = getattr(container_args, 'gpu_type', None)
+    gpu_count = getattr(container_args, 'gpu', None)
+
+    if gpu_count is not None and gpu_count == '0':
+      return None
+
+    if gpu_type is not None or gpu_count is not None:
+      return _GPU_BUILD_MACHINE_TYPE
+
+    if service is not None:
+      if k8s_object.GPU_TYPE_NODE_SELECTOR in service.template.node_selector:
+        accelerator_value = service.template.node_selector[
+            k8s_object.GPU_TYPE_NODE_SELECTOR
+        ]
+        if accelerator_value:
+          return _GPU_BUILD_MACHINE_TYPE
+
+    return None
+
   def _BuildFromSource(
       self,
       args,
@@ -392,7 +466,7 @@ class Deploy(base.Command):
         if service
         else None
     )
-    logging.debug('source_bucket: %s', source_bucket)
+    logging.debug('Existing source_bucket: %s', source_bucket)
     # We cannot use flag.isExplicitlySet(args, 'function') because it will
     # return False when user provide --function after --container.
     is_function = container_args.function
@@ -418,6 +492,11 @@ class Deploy(base.Command):
     docker_file = source + '/Dockerfile'
     base_image = self._GetBaseImageForSourceContainer(container_args, service)
     automatic_updates = self._GetAutomaticUpdates(container_args, service)
+
+    build_machine_type = None
+    if self.ReleaseTrack() == base.ReleaseTrack.ALPHA:
+      build_machine_type = self._GetMachineType(container_args, service)
+
     if os.path.exists(docker_file):
       build_type = BuildType.DOCKERFILE
       # TODO(b/310727875): check --function is not provided
@@ -477,6 +556,7 @@ class Deploy(base.Command):
         changes,
         name,
         build_worker_pool,
+        build_machine_type,
         build_env_vars,
         automatic_updates,
         source_bucket,
@@ -551,6 +631,7 @@ class Deploy(base.Command):
     x = re.search(r'gs://([^/]+)/.*', source_location)
     if x:
       return x.group(1)
+    logging.debug('source_location does not match pattern gs://([^/]+)/.*')
     return None
 
   def _GetBaseChanges(self, args):
@@ -587,10 +668,10 @@ class Deploy(base.Command):
       allow_unauth,
       has_latest,
       iap,
+      skip_build,
   ):
-    include_validate_service = bool(
-        build_from_source
-    ) and self.ReleaseTrack() in [
+    requires_build = bool(build_from_source) and not skip_build
+    include_validate_service = requires_build and self.ReleaseTrack() in [
         base.ReleaseTrack.ALPHA,
         base.ReleaseTrack.BETA,
     ]
@@ -598,11 +679,12 @@ class Deploy(base.Command):
         include_iam_policy_set=allow_unauth is not None,
         include_route=has_latest,
         include_validate_service=include_validate_service,
-        include_build=bool(build_from_source),
+        include_upload_source=bool(build_from_source),
+        include_build=requires_build,
         include_create_repo=repo_to_create is not None,
         include_iap=iap is not None,
     )
-    if build_from_source:
+    if requires_build:
       header = 'Building and deploying'
     else:
       header = 'Deploying'
@@ -704,16 +786,31 @@ class Deploy(base.Command):
     build_service_account = None
     build_env_vars = None
     build_worker_pool = None
+    build_machine_type = None
     build_changes = []
     build_from_source_container_name = ''
     enable_automatic_updates = None
     source_bucket = None
+    skip_build = False
     with serverless_operations.Connect(
         conn_context, already_activated_services
     ) as operations:
       service = operations.GetService(service_ref)
       # Build an image from source if source specified
-      if build_from_source:
+      if _IsNoBuildFromSource(self.ReleaseTrack(), build_from_source):
+        image = 'scratch'
+        skip_build = True
+        build_from_source_container_name, container_args = next(
+            iter(build_from_source.items())
+        )
+        # re-use the existing container name if it is not specified.
+        if not build_from_source_container_name and service:
+          build_from_source_container_name = (
+              service.template.container.name or ''
+          )
+        source = container_args.source
+        container_args.image = 'scratch'
+      elif build_from_source:
         (
             is_function,
             image,
@@ -726,6 +823,7 @@ class Deploy(base.Command):
             build_changes,
             build_from_source_container_name,
             build_worker_pool,
+            build_machine_type,
             build_env_vars,
             enable_automatic_updates,
             source_bucket,
@@ -780,6 +878,7 @@ class Deploy(base.Command):
             allow_unauth,
             has_latest,
             iap,
+            skip_build,
         ) as tracker:
           return operations.ReleaseService(
               service_ref,
@@ -807,12 +906,14 @@ class Deploy(base.Command):
               build_from_source_container_name=build_from_source_container_name,
               build_service_account=build_service_account,
               build_worker_pool=build_worker_pool,
+              build_machine_type=build_machine_type,
               build_env_vars=build_env_vars,
               enable_automatic_updates=enable_automatic_updates,
               is_verbose=properties.VALUES.core.verbosity.Get() == 'debug',
               source_bucket=source_bucket,
               kms_key=kms_key,
               iap_enabled=iap,
+              skip_build=skip_build,
           )
 
       try:
@@ -832,6 +933,17 @@ class Deploy(base.Command):
       return service
 
 
+def _IsNoBuildFromSource(release_track, build_from_source):
+  """Checks if this is a source deployment that should skip the Cloud Build step."""
+  if release_track != base.ReleaseTrack.ALPHA:
+    return False
+
+  if not build_from_source or len(build_from_source) != 1:
+    return False
+  container = next(iter(build_from_source.items()))[1]
+  return container.IsSpecified('no_build')
+
+
 def _ValidateArRepository(
     annotated_build_image_uri, already_activated_services
 ):
@@ -1010,12 +1122,12 @@ class BetaDeploy(Deploy):
     cls.CommonArgs(parser)
 
     # Flags specific to managed CR
-    flags.AddDefaultUrlFlag(parser)
     flags.AddDeployHealthCheckFlag(parser)
     flags.AddRegionsArg(parser)
     flags.AddScalingFlag(parser)
     flags.SERVICE_MESH_FLAG.AddToParser(parser)
     flags.AddIapFlag(parser)
+    flags.AddServiceMaxInstancesFlag(parser)
     container_args = ContainerArgGroup(cls.ReleaseTrack())
     container_parser.AddContainerFlags(parser, container_args)
 
@@ -1080,6 +1192,7 @@ class BetaDeploy(Deploy):
       allow_unauth,
       has_latest,
       iap,
+      skip_build,
   ):
     if not self.__is_multi_region:
       return super()._GetTracker(
@@ -1091,10 +1204,10 @@ class BetaDeploy(Deploy):
           allow_unauth,
           has_latest,
           iap,
+          skip_build,
       )
-    include_validate_service = bool(
-        build_from_source
-    ) and self.ReleaseTrack() in [
+    requires_build = bool(build_from_source) and not skip_build
+    include_validate_service = requires_build and self.ReleaseTrack() in [
         base.ReleaseTrack.ALPHA,
         base.ReleaseTrack.BETA,
     ]
@@ -1102,7 +1215,7 @@ class BetaDeploy(Deploy):
         include_iam_policy_set=allow_unauth is not None,
         include_route=has_latest,
         include_validate_service=include_validate_service,
-        include_build=bool(build_from_source),
+        include_build=requires_build,
         include_create_repo=repo_to_create is not None,
         include_create_revision=True,
         include_iap=iap is not None,
@@ -1139,7 +1252,6 @@ class AlphaDeploy(BetaDeploy):
 
     # Flags specific to managed CR
     flags.AddDeployHealthCheckFlag(parser)
-    flags.AddDefaultUrlFlag(parser)
     flags.AddIapFlag(parser)
     flags.AddRuntimeFlag(parser)
     flags.AddServiceMaxInstancesFlag(parser)
@@ -1152,9 +1264,11 @@ class AlphaDeploy(BetaDeploy):
     flags.ENABLE_WORKLOAD_CERTIFICATE_FLAG.AddToParser(parser)
     flags.MESH_DATAPLANE_FLAG.AddToParser(parser)
     container_args = ContainerArgGroup(cls.ReleaseTrack())
+    container_args.AddArgument(flags.ReadinessProbeFlag())
     container_parser.AddContainerFlags(parser, container_args)
     flags.AddDelegateBuildsFlag(parser)
     flags.AddOverflowScalingFlag(parser)
+    flags.AddPresetFlag(parser)
 
 
 AlphaDeploy.__doc__ = Deploy.__doc__
